@@ -8,12 +8,14 @@
 #makeExampleKnot (k governs the output. k = TRUE returns a knot, FALSE returns a link.
 makeExampleKnot <- function(k = TRUE) {
 	if(k) {
-		data(Rolfsen.table)
+		Rolfsen.table <- NULL; rm(Rolfsen.table)
+		data(Rolfsen.table, package='Rknots')
 		knot <- Rolfsen.table[[ sample(1 : length(Rolfsen.table), size = 1) ]]
 		return( knot )
 	}
 	else {
-		data(link.table)
+		link.table <- NULL; rm(link.table)
+		data(link.table, package='Rknots')
 		link <- link.table[[ sample(1 : length(link.table), size = 1) ]]
 		return( link )
 	}
